@@ -36,6 +36,9 @@
 #include <gio/gio.h>
 #include <gdk/gdk.h>
 #include <gtk/gtk.h>
+#if 0
+#include <libupower-glib/upower.h>
+#endif
 
 #define GNOME_DESKTOP_USE_UNSTABLE_API
 
@@ -91,6 +94,10 @@ struct GsdXrandrManagerPrivate {
         GnomeRRScreen *rw_screen;
         gboolean running;
 
+#if 0
+        UpClient *upower_client;
+#endif
+
         GSettings       *settings;
         GDBusNodeInfo   *introspection_data;
         guint            name_id;
@@ -98,7 +105,7 @@ struct GsdXrandrManagerPrivate {
         GCancellable    *bus_cancellable;
 
         GsdDeviceMapper  *device_mapper;
-        GdkDeviceManager *device_manager;
+        GsdDeviceManager *device_manager;
         guint             device_added_id;
         guint             device_removed_id;
 
@@ -454,7 +461,11 @@ config_is_all_off (GnomeRRConfig *config)
 static gboolean
 laptop_lid_is_closed (GsdXrandrManager *manager)
 {
-        return FALSE; //up_client_get_lid_is_closed (manager->priv->upower_client);
+#if 0
+        return up_client_get_lid_is_closed (manager->priv->upower_client);
+#else
+        return FALSE;
+#endif
 }
 
 static gboolean
@@ -1155,21 +1166,27 @@ get_allowed_rotations_for_output (GnomeRRConfig *config,
 
 static void
 manager_device_added (GsdXrandrManager *manager,
-                      GdkDevice        *device)
+                      GsdDevice        *device)
 {
-        if (gdk_device_get_device_type (device) == GDK_DEVICE_TYPE_MASTER ||
-            gdk_device_get_source (device) != GDK_SOURCE_TOUCHSCREEN)
+        GsdDeviceType type;
+
+        type = gsd_device_get_device_type (device);
+
+        if ((type & GSD_DEVICE_TYPE_TOUCHSCREEN) == 0)
                 return;
 
-        gsd_device_mapper_add_input (manager->priv->device_mapper, device, NULL);
+        gsd_device_mapper_add_input (manager->priv->device_mapper, device);
 }
 
 static void
 manager_device_removed (GsdXrandrManager *manager,
-                        GdkDevice        *device)
+                        GsdDevice        *device)
 {
-        if (gdk_device_get_device_type (device) == GDK_DEVICE_TYPE_MASTER ||
-            gdk_device_get_source (device) != GDK_SOURCE_TOUCHSCREEN)
+        GsdDeviceType type;
+
+        type = gsd_device_get_device_type (device);
+
+        if ((type & GSD_DEVICE_TYPE_TOUCHSCREEN) == 0)
                 return;
 
         gsd_device_mapper_remove_input (manager->priv->device_mapper, device);
@@ -1178,15 +1195,10 @@ manager_device_removed (GsdXrandrManager *manager,
 static void
 manager_init_devices (GsdXrandrManager *manager)
 {
-        GdkDisplay *display;
         GList *devices, *d;
-        GdkScreen *screen;
-
-        screen = gdk_screen_get_default ();
-        display = gdk_screen_get_display (screen);
 
         manager->priv->device_mapper = gsd_device_mapper_get ();
-        manager->priv->device_manager = gdk_display_get_device_manager (display);
+        manager->priv->device_manager = gsd_device_manager_get ();
         manager->priv->device_added_id =
                 g_signal_connect_swapped (manager->priv->device_manager, "device-added",
                                           G_CALLBACK (manager_device_added), manager);
@@ -1194,8 +1206,8 @@ manager_init_devices (GsdXrandrManager *manager)
                 g_signal_connect_swapped (manager->priv->device_manager, "device-removed",
                                   G_CALLBACK (manager_device_removed), manager);
 
-        devices = gdk_device_manager_list_devices (manager->priv->device_manager,
-                                                   GDK_DEVICE_TYPE_SLAVE);
+        devices = gsd_device_manager_list_devices (manager->priv->device_manager,
+                                                   GSD_DEVICE_TYPE_TOUCHSCREEN);
 
         for (d = devices; d; d = d->next)
                 manager_device_added (manager, d->data);
@@ -1221,6 +1233,10 @@ on_rr_screen_acquired (GObject      *object,
                 return;
         }
 
+#if 0
+        manager->priv->upower_client = up_client_new ();
+#endif
+
         log_msg ("State of screen at startup:\n");
         log_screen (manager->priv->rw_screen);
 
@@ -1274,6 +1290,14 @@ gsd_xrandr_manager_stop (GsdXrandrManager *manager)
                 manager->priv->rw_screen = NULL;
         }
 
+#if 0
+        if (manager->priv->upower_client != NULL) {
+                g_signal_handlers_disconnect_by_data (manager->priv->upower_client, manager);
+                g_object_unref (manager->priv->upower_client);
+                manager->priv->upower_client = NULL;
+        }
+#endif
+
         if (manager->priv->name_id != 0)
                 g_bus_unown_name (manager->priv->name_id);
 
